package sysinfo

import (
	"os/exec"
)

// PackageManager is an abstraction over distro package tooling.
type PackageManager interface {
	Distro() string
	InstallPackages(pkgs ...string) error
	ExecExists(bin string) bool
}

/* ------------------------------------------------------------------ */
/*  aptManager (Ubuntu / Debian)                                      */
/* ------------------------------------------------------------------ */

type aptManager struct {
	logf func(string, ...any)
}

func newPackageManager(logf func(string, ...any)) PackageManager {
	return &aptManager{logf: logf}
}

func (a *aptManager) Distro() string { return "ubuntu" }

func (a *aptManager) ExecExists(bin string) bool {
	_, err := exec.LookPath(bin)
	return err == nil
}

func (a *aptManager) InstallPackages(pkgs ...string) error {
	args := append([]string{"-y", "install"}, pkgs...)
	cmd := exec.Command("apt-get", args...)
	cmd.Env = append(cmd.Env, "DEBIAN_FRONTEND=noninteractive")
	cmd.Stdout = nil
	cmd.Stderr = nil
	a.logf("apt install %v", pkgs)
	return cmd.Run()
}
